@@ -6,7 +6,7 @@ use Sub::Infix;
 use Exporter qw(import);
 our @EXPORT = qw(in);
 
-our $VERSION = '0.0002'; # VERSION
+our $VERSION = '0.0003'; # VERSION
 
 sub install {
     my ($class, %args) = @_;
@@ -31,7 +31,7 @@ Syntax::Feature::In - provides an "in" operator as a replacement for smartmatch
 
 =head1 VERSION
 
-version 0.0002
+version 0.0003
 
 =head1 SYNOPSIS
 
@@ -42,14 +42,15 @@ version 0.0002
 =head1 DESCRIPTION
 
 This modules imports the C<in> operator.
-It can be used in three equivalent forms:
+It can be used as in infix operator:
 
     $foo |in| $bar
-    $foo /in/ $bar
-    $foo <<in>> $bar
 
-It does a simplified version of smartmatch.
-See the C<match> function from L<match::simple> for more details.
+Or in a more traditional way:
+
+    in->($foo, $bar)
+
+It does a simplified version of smartmatch as described in L<match::simple>.
 
 =head1 SEE ALSO
 
